==> jc-1.4.0.tar.gz: polyglot/visit/ConstantFolder.h <==
// public class polyglot.visit.ConstantFolder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5d560b7b79a8692b polyglot_visit_ConstantFolder
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_ConstantFolder_H_
#define _JC_polyglot_visit_ConstantFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_ConstantFolder$sub_refs	_jc_polyglot_visit_ConstantFolder$sub_refs;
typedef struct _jc_polyglot_visit_ConstantFolder$sub_nonrefs	_jc_polyglot_visit_ConstantFolder$sub_nonrefs;
typedef struct _jc_polyglot_visit_ConstantFolder$refs	_jc_polyglot_visit_ConstantFolder$refs;
typedef struct _jc_polyglot_visit_ConstantFolder$nonrefs	_jc_polyglot_visit_ConstantFolder$nonrefs;
typedef struct _jc_polyglot_visit_ConstantFolder$object	_jc_polyglot_visit_ConstantFolder$object;

typedef const struct _jc_polyglot_visit_ConstantFolder$vmethods	_jc_polyglot_visit_ConstantFolder$vmethods;
typedef const struct _jc_polyglot_visit_ConstantFolder$vtable	_jc_polyglot_visit_ConstantFolder$vtable;
typedef const struct _jc_polyglot_visit_ConstantFolder$vtype	_jc_polyglot_visit_ConstantFolder$vtype;

// Constructors
extern void _jc_polyglot_visit_ConstantFolder$method$_init$5f44ce139b44c505(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_ConstantFolder$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_ConstantFolder$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
extern struct _jc_object *_jc_polyglot_visit_ConstantFolder$method$nodeFactory$32826050387dc827(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *);
extern struct _jc_object *_jc_polyglot_visit_ConstantFolder$method$typeSystem$c9dab312e784024e(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$leave$cf18a0cab654af63;
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$nodeFactory$32826050387dc827;
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$typeSystem$c9dab312e784024e;

// Virtual methods structure
struct _jc_polyglot_visit_ConstantFolder$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
	struct _jc_object	*(*nodeFactory$32826050387dc827)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *);
	struct _jc_object	*(*typeSystem$c9dab312e784024e)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *);
};

// Vtable
struct _jc_polyglot_visit_ConstantFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_ConstantFolder$vmethods	polyglot_visit_ConstantFolder;
};

// Vtype
struct _jc_polyglot_visit_ConstantFolder$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ConstantFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ConstantFolder$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*nf;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ConstantFolder$refs {
    _jc_polyglot_visit_ConstantFolder$sub_refs	polyglot_visit_ConstantFolder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ConstantFolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ConstantFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_ConstantFolder$sub_nonrefs	polyglot_visit_ConstantFolder;
};

// Object instance structure
struct _jc_polyglot_visit_ConstantFolder$object {
	_jc_polyglot_visit_ConstantFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ConstantFolder$vtype	*vtype;
	_jc_polyglot_visit_ConstantFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ConstantFolder$vtype _jc_polyglot_visit_ConstantFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ConstantFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ConstantFolder$class_object;

#endif	/* _JC_polyglot_visit_ConstantFolder_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/ConstantFolder.h <==
// public class polyglot.visit.ConstantFolder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5d560b7b79a8692b polyglot_visit_ConstantFolder
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_ConstantFolder_H_
#define _JC_polyglot_visit_ConstantFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_ConstantFolder$sub_refs	_jc_polyglot_visit_ConstantFolder$sub_refs;
typedef struct _jc_polyglot_visit_ConstantFolder$sub_nonrefs	_jc_polyglot_visit_ConstantFolder$sub_nonrefs;
typedef struct _jc_polyglot_visit_ConstantFolder$refs	_jc_polyglot_visit_ConstantFolder$refs;
typedef struct _jc_polyglot_visit_ConstantFolder$nonrefs	_jc_polyglot_visit_ConstantFolder$nonrefs;
typedef struct _jc_polyglot_visit_ConstantFolder$object	_jc_polyglot_visit_ConstantFolder$object;

typedef const struct _jc_polyglot_visit_ConstantFolder$vmethods	_jc_polyglot_visit_ConstantFolder$vmethods;
typedef const struct _jc_polyglot_visit_ConstantFolder$vtable	_jc_polyglot_visit_ConstantFolder$vtable;
typedef const struct _jc_polyglot_visit_ConstantFolder$vtype	_jc_polyglot_visit_ConstantFolder$vtype;

// Constructors
extern void _jc_polyglot_visit_ConstantFolder$method$_init$5f44ce139b44c505(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_ConstantFolder$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_ConstantFolder$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_ConstantFolder$method$nodeFactory$32826050387dc827(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_ConstantFolder$method$typeSystem$c9dab312e784024e(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$leave$cf18a0cab654af63;
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$nodeFactory$32826050387dc827;
extern _jc_method _jc_polyglot_visit_ConstantFolder$method_info$typeSystem$c9dab312e784024e;

// Virtual methods structure
struct _jc_polyglot_visit_ConstantFolder$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*nodeFactory$32826050387dc827)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*typeSystem$c9dab312e784024e)(_jc_env *, struct _jc_polyglot_visit_ConstantFolder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_ConstantFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_ConstantFolder$vmethods	polyglot_visit_ConstantFolder;
};

// Vtype
struct _jc_polyglot_visit_ConstantFolder$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ConstantFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ConstantFolder$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*nf;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ConstantFolder$refs {
    _jc_polyglot_visit_ConstantFolder$sub_refs	polyglot_visit_ConstantFolder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ConstantFolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ConstantFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_ConstantFolder$sub_nonrefs	polyglot_visit_ConstantFolder;
};

// Object instance structure
struct _jc_polyglot_visit_ConstantFolder$object {
	_jc_polyglot_visit_ConstantFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ConstantFolder$vtype	*vtype;
	_jc_polyglot_visit_ConstantFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ConstantFolder$vtype _jc_polyglot_visit_ConstantFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ConstantFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ConstantFolder$class_object;

#endif	/* _JC_polyglot_visit_ConstantFolder_H_ */
